@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2018 Procube Co., Ltd.
@@ -47,6 +47,14 @@ DOCUMENTATION = r'''
           description: whether repository node is separated from swarm nodes
           type: bool
           default: true
+        shared_repository:
+          description: whether repository node is placed on mother server.
+          type: dict
+          suboptions:
+            context_dir:
+              description: context directory
+            ssh_port:
+              description: The port number forwarded to the port where sshd is listening
         cidr:
           description: cidr of vpc
           required: true
@@ -288,6 +296,8 @@ class Stage:
       self.inventory.set_variable(mother_name, 'hive_kickstart_config', self.stage['kickstart_config'])
     if 'filestore_cidr' in self.stage:
       self.inventory.set_variable(mother_name, 'hive_filestore_cidr', self.stage['filestore_cidr'])
+    if 'shared_repository' in self.stage:
+      self.inventory.set_variable(mother_name, 'hive_shared_repository', self.stage['shared_repository'])
     if 'subnets' not in self.stage:
       try:
         net = ipaddress.ip_network(self.stage['cidr'])
@@ -334,6 +344,9 @@ class Stage:
 
   def add_hives(self):
     separate_repository = self.stage.get('separate_repository', True)
+    shared_repository = self.stage.get('shared_repository', False)
+    if not separate_repository and shared_repository:
+      raise Error("plese set separate_repository True, when use shared_repository")
     number_of_hosts = self.stage.get('number_of_hosts', 4 if separate_repository else 3)
     custom_hostname = self.stage.get('custom_hostname', 'hive')
     hostname_pattern = r'^[a-z0-9][a-z0-9-]*[a-z0-9]$'
@@ -356,6 +369,8 @@ class Stage:
         self.inventory.set_variable(host_name, 'hive_internal_cidr_v6', self.stage['internal_cidr_v6'])
       if 'kms_key_id' in self.stage:
         self.inventory.set_variable(host_name, 'hive_kms_key_id', self.stage['kms_key_id'])
+      if 'shared_repository' in self.stage:
+        self.inventory.set_variable(host_name, 'hive_shared_repository', self.stage['shared_repository'])
       if idx == number_of_hosts - 1:
         if not separate_repository:
           self.inventory.add_host(host_name, group='hives')
